==> kubernetes-model-networking-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IngressRuleFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class IngressRuleFluentImpl<A extends io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluent<A>{
  public IngressRuleFluentImpl() {
  }
  public IngressRuleFluentImpl(io.fabric8.kubernetes.api.model.networking.v1.IngressRule instance) {
    this.withHost(instance.getHost()); 
    this.withHttp(instance.getHttp()); 
  }
  private java.lang.String host;
  private io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueBuilder http;
  public java.lang.String getHost() {
    return this.host;
  }
  public A withHost(java.lang.String host) {
    this.host=host; return (A) this;
  }
  public java.lang.Boolean hasHost() {
    return this.host != null;
  }
  
  /**
   * Method is deprecated. use withHost instead.
   */
  @java.lang.Deprecated
  public A withNewHost(java.lang.String arg0) {
    return (A)withHost(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildHttp instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValue getHttp() {
    return this.http!=null?this.http.build():null;
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValue buildHttp() {
    return this.http!=null?this.http.build():null;
  }
  public A withHttp(io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValue http) {
    _visitables.get("http").remove(this.http);
    if (http!=null){ this.http= new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueBuilder(http); _visitables.get("http").add(this.http);} return (A) this;
  }
  public java.lang.Boolean hasHttp() {
    return this.http != null;
  }
  public io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluent.HttpNested<A> withNewHttp() {
    return new io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluentImpl.HttpNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluent.HttpNested<A> withNewHttpLike(io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValue item) {
    return new io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluentImpl.HttpNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluent.HttpNested<A> editHttp() {
    return withNewHttpLike(getHttp());
  }
  public io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluent.HttpNested<A> editOrNewHttp() {
    return withNewHttpLike(getHttp() != null ? getHttp(): new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluent.HttpNested<A> editOrNewHttpLike(io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValue item) {
    return withNewHttpLike(getHttp() != null ? getHttp(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IngressRuleFluentImpl that = (IngressRuleFluentImpl) o;
    if (host != null ? !host.equals(that.host) :that.host != null) return false;
    if (http != null ? !http.equals(that.http) :that.http != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(host,  http,  super.hashCode());
  }
  public class HttpNestedImpl<N> extends io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluentImpl<io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluent.HttpNested<N>> implements io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluent.HttpNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    HttpNestedImpl(io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValue item) {
      this.builder = new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueBuilder(this, item);
    }
    HttpNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueBuilder(this);
    }
    io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueBuilder builder;
    public N and() {
      return (N) IngressRuleFluentImpl.this.withHttp(builder.build());
    }
    public N endHttp() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-networking-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IngressRuleFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class IngressRuleFluentImpl<A extends io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluent<A>{
  public IngressRuleFluentImpl() {
  }
  public IngressRuleFluentImpl(io.fabric8.kubernetes.api.model.networking.v1.IngressRule instance) {
    this.withHost(instance.getHost()); 
    this.withHttp(instance.getHttp()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String host;
  private io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueBuilder http;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getHost() {
    return this.host;
  }
  public A withHost(java.lang.String host) {
    this.host=host; return (A) this;
  }
  public java.lang.Boolean hasHost() {
    return this.host != null;
  }
  
  /**
   * Method is deprecated. use withHost instead.
   */
  @java.lang.Deprecated
  public A withNewHost(java.lang.String arg0) {
    return (A)withHost(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildHttp instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValue getHttp() {
    return this.http!=null?this.http.build():null;
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValue buildHttp() {
    return this.http!=null?this.http.build():null;
  }
  public A withHttp(io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValue http) {
    _visitables.get("http").remove(this.http);
    if (http!=null){ this.http= new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueBuilder(http); _visitables.get("http").add(this.http);} return (A) this;
  }
  public java.lang.Boolean hasHttp() {
    return this.http != null;
  }
  public io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluent.HttpNested<A> withNewHttp() {
    return new io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluentImpl.HttpNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluent.HttpNested<A> withNewHttpLike(io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValue item) {
    return new io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluentImpl.HttpNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluent.HttpNested<A> editHttp() {
    return withNewHttpLike(getHttp());
  }
  public io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluent.HttpNested<A> editOrNewHttp() {
    return withNewHttpLike(getHttp() != null ? getHttp(): new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluent.HttpNested<A> editOrNewHttpLike(io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValue item) {
    return withNewHttpLike(getHttp() != null ? getHttp(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IngressRuleFluentImpl that = (IngressRuleFluentImpl) o;
    if (host != null ? !host.equals(that.host) :that.host != null) return false;
    if (http != null ? !http.equals(that.http) :that.http != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(host,  http,  additionalProperties,  super.hashCode());
  }
  public class HttpNestedImpl<N> extends io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluentImpl<io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluent.HttpNested<N>> implements io.fabric8.kubernetes.api.model.networking.v1.IngressRuleFluent.HttpNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    HttpNestedImpl(io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValue item) {
      this.builder = new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueBuilder(this, item);
    }
    HttpNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueBuilder(this);
    }
    io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueBuilder builder;
    public N and() {
      return (N) IngressRuleFluentImpl.this.withHttp(builder.build());
    }
    public N endHttp() {
      return and();
    }
    
  }
  
}
